@@ -53,6 +53,31 @@ class GitLabProjectService:
         self.project.members.delete(user.id)
 
 
+class GitLabCiVariablesService:
+    def __init__(self, project: Project) -> None:
+        self.logger = get_logger(self.__class__.__name__)
+
+        self.project = project
+
+    def get_variables(self, variable: dict[str, str]) -> None:
+        self.project.variables.get(variable["key"])
+
+    def create_variables(self, variable: dict[str, str]) -> None:
+        self.project.variables.create(variable)
+
+    def update_variables(self, variable: dict[str, str]) -> None:
+        self.project.variables.update(variable["key"], variable)
+
+    def delete_variables(self, variable: dict[str, str]) -> None:
+        self.project.variables.delete(variable["key"])
+
+    def create_or_update_variables(self, variable: dict[str, str]) -> None:
+        if variable["key"] in [var.key for var in self.project.variables.list()]:
+            self.logger.debug(f"⚠️ Variable '{variable["key"]}' already exists. It will be updated.")
+            self.delete_variables(variable)
+        self.create_variables(variable)
+
+
 class GitLabPipelineService:
     def __init__(self, project: Project) -> None:
         self.logger = get_logger(self.__class__.__name__)
@@ -276,6 +301,7 @@ class GitLabClient:
 
         project = self.gitlab.projects.get(project_id)
         self.project = GitLabProjectService(gitlab_client=self.gitlab, project=project)
+        self.ci_variables = GitLabCiVariablesService(project=project)
         self.pipeline = GitLabPipelineService(project=project)
         self.branch = GitLabBranchService(project=project)
         self.tag = GitLabTagService(project=project)
